;; Generated package description from swiper.el  -*- no-byte-compile: t -*-
(define-package "swiper" "0.14.0.0.20231025.114212" "Isearch with an overview.  Oh, man!" '((emacs "24.5") (ivy "0.14.0")) :commit "59356a97ef7febc908ad8e014fd45ea2d8f37d33" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Oleh Krehel" . "ohwoeowho@gmail.com") :keywords '("matching") :url "https://github.com/abo-abo/swiper")
